@@ -6,8 +6,6 @@ from skimage.metrics import structural_similarity as ssim
 import glob, os
 import pandas
 
-import time
-
 class Similarity:
     
     def __init__(self):
@@ -105,15 +103,11 @@ class AvaluateListOfImages:
             similar = False
             
         return similar
-        
-    def listRepetidos(self, pathOrigin, removeSimilar = True, resize = False, scale_percent = 100):
-        listOfImages = self.loadImageList(pathOrigin)
-        listOfImages.sort()
-        
+    
+    def checkList(self, listOfImages, removeSimilar = True, resize = False, scale_percent = 100):
         similarity = Similarity()
-        
-        listaRestante = listOfImages[:]
         listToRemove = []
+        
         for i, image in enumerate(listOfImages):
             imageA = cv2.imread(image)
             
@@ -148,7 +142,36 @@ class AvaluateListOfImages:
                             if removeSimilar:
                                 #print(f'Imagem: {nameImage2} semelhante a {nameImage}')
                                 listToRemove.append(image2)
+        return listToRemove
                                 
+    def listRepetidos(self, pathOrigin, removeSimilar = True, resize = False, scale_percent = 100):
+        listOfImages = self.loadImageList(pathOrigin)
+        listOfImages.sort()
+        
+        
+        
+        listaRestante = listOfImages[:]
+        listToRemove = []
+        
+        if len(listOfImages) > 100:
+            cntInicial = 0
+            cntFinal = 100
+            
+            while cntFinal < len(listOfImages):
+                print(f'Analisando da imagem {cntInicial} até {cntFinal}')
+                listPartial = listOfImages[cntInicial:cntFinal]
+            
+                listResidual = self.checkList(listPartial)
+                listToRemove = listToRemove + listResidual
+            
+                cntInicial = cntFinal
+                cntFinal = cntFinal + 100
+            
+            
+        else:
+            listToRemove = self.checkList(listOfImages, removeSimilar, resize, scale_percent)
+            
+                  
         for elementToRemove in listToRemove:
             try:
                 listaRestante.remove(elementToRemove)
@@ -217,3 +240,16 @@ class AvaluateListOfImages:
                 
         return listaRestante, listOfBlacks
                 
+if __name__ == '__main__':
+    avLoI = AvaluateListOfImages()
+    listaLimpa, listaRepetidos = avLoI.listRepetidos('/media/alancaio/Elements/DataBase/@Tech/Bovine/Raw/img/Agua Tirada/120',
+                                                     True,
+                                                     True,
+                                                     50)
+    
+    listaNomesRepetidos = []
+    for nomeImagem in listaRepetidos:
+        listaNomesRepetidos.append(nomeImagem.split('/')[-1])
+
+    avLoI.removerRepetidos(listaRepetidos)
+    
\ No newline at end of file
